@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::Shippo;
 # ABSTRACT: A Shippo Perl API wrapper
-our $VERSION = '0.0.11';
+our $VERSION = '0.0.12';
 require WebService::Shippo::Entities;
 use boolean ':all';
 use Params::Callbacks ( 'callbacks', 'callback' );
@@ -62,11 +62,11 @@ BEGIN {
 
 =head1 NAME
 
-WebService::Shippo - A Shippo API Perl Wrapper (coming soon)
+WebService::Shippo - A Shippo API Perl Wrapper (pre-release)
 
 =head1 VERSION
 
-0.0.11 (2015-11-02)
+version 0.0.12
 
 =head1 SYNOPIS
 
@@ -99,9 +99,9 @@ Don't have an account? Sign up at L<https://goshippo.com/>
         metadata       => 'Customer ID 123456'
     );
     
-    print 'Success with Address 1 : ', $address
+    print 'Success with Address 1 : ', $address->to_json;
 
-All being well, you should see something like the following output:
+All being well, you should see something like this:
 
     Success with Address 1 : {
        "city" : "Woodridge",
