@@ -3,7 +3,7 @@ use warnings;
 
 package WebService::Shippo::Entities;
 require WebService::Shippo::Object;
-require WebService::Shippo::ObjectList;
+require WebService::Shippo::Collection;
 require WebService::Shippo::Resource;
 require WebService::Shippo::Address;
 require WebService::Shippo::CarrierAccount;
