@@ -7,15 +7,17 @@ use base (
     'WebService::Shippo::Resource',
     'WebService::Shippo::Creator',
     'WebService::Shippo::Fetcher',
-    'WebService::Shippo::Lister',
-
 );
 
-sub api_resource { 'manifests' }
+sub api_resource ()     { 'manifests' }
+sub collection_class () { 'WebService::Shippo::Manifests' }
+sub item_class ()       { __PACKAGE__ }
 
 package    # Hide from PAUSE
-    WebService::Shippo::ManifestList;
-use base ( 'WebService::Shippo::ObjectList' );
+    WebService::Shippo::Manifests;
+use base ( 'WebService::Shippo::Collection' );
+sub item_class ()       { 'WebService::Shippo::Manifest' }
+sub collection_class () { __PACKAGE__ }
 
 BEGIN {
     no warnings 'once';
