@@ -6,14 +6,17 @@ package WebService::Shippo::Rate;
 use base (
     'WebService::Shippo::Resource',
     'WebService::Shippo::Fetcher',
-    'WebService::Shippo::Lister',
 );
 
-sub api_resource { 'rates' }
+sub api_resource ()     { 'rates' }
+sub collection_class () { 'WebService::Shippo::Rates' }
+sub item_class ()       { __PACKAGE__ }
 
 package    # Hide from PAUSE
-    WebService::Shippo::RateList;
-use base ( 'WebService::Shippo::ObjectList' );
+    WebService::Shippo::Rates;
+use base ( 'WebService::Shippo::Collection' );
+sub item_class ()       { 'WebService::Shippo::Rate' }
+sub collection_class () { __PACKAGE__ }
 
 BEGIN {
     no warnings 'once';
